"use client"

import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { CommissionExtra, CommissionOption, CommissionType, CommissionTypeExtra, CommissionTypeOption } from "@/generated/prisma";

type CommissionTypeWithItems = CommissionType & {
  options: (CommissionTypeOption & {
    option: CommissionOption | null
  })[]
  extras: (CommissionTypeExtra & {
    extra: CommissionExtra | null
  })[]
}

export default function ListTypes({ types }: { types: CommissionTypeWithItems[] }) {
  return (
    <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-4">
      {types.map(type => (
        <Card key={type.id}>
          <CardHeader>
            <CardTitle className="text-xl truncate">{type.name}</CardTitle>
            <CardDescription>{type.description}</CardDescription>
          </CardHeader>
          <CardContent className="flex flex-col justify-start gap-4">
            <div>
              <h4 className="font-semibold">Options</h4>
              <ul className="pl-4 list-disc">
                {type.options.map((opt) => (
                  <li key={opt.id}>
                    {opt.option?.name}:{" "}
                    {opt.price !== null
                      ? `${opt.price}€`
                      : opt.pricePercent
                        ? `+${opt.pricePercent}%`
                        : opt.priceRange
                          ? `${opt.priceRange}€`
                          : "Included"}
                  </li>
                ))}
              </ul>
            </div>
            <div>
              <h4 className="font-semibold">Extras</h4>
              <ul className="pl-4 list-disc">
                {type.extras.map((ext) => (
                  <li key={ext.id}>
                    {ext.extra?.name}:{" "}
                    {ext.price !== null
                      ? `${ext.price}€`
                      : ext.pricePercent
                        ? `+${ext.pricePercent}%`
                        : ext.priceRange
                          ? `${ext.priceRange}€`
                          : "Included"}
                  </li>
                ))}
              </ul>
            </div>
          </CardContent>
        </Card>
      ))}
    </div>
  );
}